' === ConTester.bas ================================================
' Program implements a continuity tester with an "auto-off" feature.
' If no "short" has been deteced within a ten minute period,
' the program disconnects power from the circuit.

' Two standard multi-meter probes are connected to the circuit,  [1]
' one to the junction of a 10k/10k voltage divider attached
' to pin C.1, and the other one to ground.

' === Directives ===
  #com 4                 'specify serial port
  #picaxe 08M2           'specify processor
  #terminal off          'disable the terminal window
  #no_data               'save time downloading

' === Constants ====
  symbol   LED = C.0     '"I'm alive" LED on pin C.0
  symbol probe = C.1     'one probe on C.1 (other one on ground)
  symbol piezo = C.2     'piezo beeper on pin C.2
  symbol   SSR = C.4     'SSR controlled by pin C.4 (high = on)
  
' === Variables ====
  symbol ADCval = b0     'value of the 8-bit ADC reading
  symbol  alive = b1     'used to blink "I'm alive" LED
	
' === Begin Main Program ===========================================
  high SSR                        'connect main power ASAP
  pwmout pwmdiv16, piezo, 124, 0  'configure PWM (off)           [2]

do
  if alive = 0 then               'once every 256 iterations,    [3]
    high LED                      'briefly blink LED
    pause 100
    low LED
  endif
  
  inc alive                       'automatic "roll-over" at 255  [4]
  readadc probe, ADCval           'get ADCval 
  
  if ADCval < 3 then              'if "short" is detected        [5]
    time = 0                      '  reset the seconds timer     [6]
    pwmduty piezo,250             '  and beep                    [7]
  else                            'else
    pwmduty piezo,0               '  silence the piezo beeper    [8]
  endif
  
  if time > 600 then              '10 minutes with no "short"    [9]
    low SSR                       '  so disconnect main power
  endif
loop